//
// Title:   CorrelationDialogImpl.h
// Created: November 28, 2002
// Authors: Daniel Cotting
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef CORRELATIONDIALOGIMPL_H
#define CORRELATIONDIALOGIMPL_H

#include "../UI/CorrelationDialog.h"

/**
 * Correlation dialog for the public and private watermarking scheme.
 */
class CorrelationDialogImpl : public CorrelationDialog
{
  Q_OBJECT

public:

	/**
	 * Constructor for the correlation dialog of the watermarking plugin.
	 *
	 * Dimension of the canvas is 470 x 220 and displays a plot containing a
	 * threshold and a correlation value for each x-Coordinate. Only the first
	 * 470 values will be plotted. The remaining values are simply ignored.
	 * Threshold values are plotted using blue color, whereas the correlation
	 * value is plotted green in case the correlation is larger than the 
	 * threshold value or red if this is not the case.
	 *
	 * @param correlationList	List containing the <tt>float</tt> correlation values.
	 * @param thresholdList		List containing the <tt>float</tt> threshold values.
	 * @param parent			Standard QT dialog parameter.
	 * @param name				Standard QT dialog parameter.
	 * @param modal				Standart QT dialog parameter.
	 * @param f					Standard QT dialog parameter.
	 */
    CorrelationDialogImpl(QList<float>* correlationList, QList<float>* thresholdList, QWidget* parent = 0, const char* name = 0, bool modal = FALSE, WFlags f = 0 );

public slots:

private:

};

#endif

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
