//
// Title:   RCA.cpp (originally PCA_v01.c)
// Created: November 28, 2002
// Authors: Daniel Cotting (for adaptation to PointShop3D, main authors see below)
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.

#ifndef _PCA_H_EA6C0EE0_BC30_11d5_B625_A58C4DF45B22_INCLUDED
#define _PCA_H_EA6C0EE0_BC30_11d5_B625_A58C4DF45B22_INCLUDED

#include <gsl/gsl_matrix.h>
#include <gsl/gsl_blas.h>
#include <gsl/gsl_eigen.h>

/** 
 * Principal Component Analysis code using GSL.
 */
class PCA
{

public:
	/* ****************************************************************************************
                           
	 Eigensystem of the variance-covariance matrix will be stored 
	 in a linked list of elements of structure eigenRec.

	***************************************************************************************** */

	struct eigenRec {

		char *annotation;
		int cols;
		double eigenvalue;
		gsl_vector *eigenvector;
		struct eigenRec *next;

	};

	/* ********************************************************************************** 

	 These typedefs will allow us to easily use the linked list representing
	  the datalist and eigensystem throughout our code.

	************************************************************************************ */	

	typedef struct eigenRec EigenRec;
	typedef EigenRec *EigenList;

	PCA() {};
	void createCovarianceMatrix( gsl_matrix *m, gsl_matrix *sm);
	void calculateEigenSystem( gsl_matrix *m, EigenList eList);
	void outputCovarMatrix( EigenList eList, gsl_matrix *m);
	void outputEigenSystem( EigenList eList);
	EigenList initializeEigenList(int cols);

private:
	void addEigenLink( char *annotation, EigenList elist );


};

#endif // _CRC_32_H_EA6C0EE0_BC30_11d5_B625_A58C4DF45B22_INCLUDED

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
