//
// Title:   PatchBuilderInterface.h
// Created: November 28, 2002
// Authors: Daniel Cotting
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __PATCHBUILDERINTERFACE_H_
#define __PATCHBUILDERINTERFACE_H_

#include <qobject.h>

#include "../../../Core/Interfaces/src/PluginInterface.h"
#include "../../../Core/Interfaces/src/SurfelInterface.h"
#include "Patch.h"
#include "MySurfelList.h"
#include "ModuleInterface.h"

/**
 * Takes a list of surfels and creates patches each containing a part of the surfels.
 * This is used to create smaller collections of surfels that can be processed
 * independently from each other. This results in better robustness against cropping
 * attacks. Furthermore some algorithms work faster on patches than on an entire object.
 */
class PatchBuilderInterface: public ModuleInterface {

public:

	/**
	 * List fo patches.
	 */
	typedef QList<Patch> PatchList;

	/**
	 * Takes a list of srufels and creates parches each containing a part of the surfels.
	 * 
	 * @param surfelList	The list of surfels that have to be subdivided into patches.
	 * @return				The list of patches that have been generated.
	 */
	virtual PatchList* buildPatches(MySurfelList* surfelList) = 0;

	/**
	 * Returns the name of this module.
	 *
	 * @return The name of this module.
	 */
	virtual const char* getModuleName() const = 0;

	/**
	 * Returns the description of this module.
	 *
	 * @return The description of this module.
	 */
	virtual const char* getModuleDescription() const = 0;

protected:

	/**
	 * Each patch has to contain a minimum number of points. 
	 */
	unsigned int nofMinimumPointsPerPatch;

};

#endif __PATCHBUILDERINTERFACE_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
