//
// Title:   PlaneProjection.h
// Created: November 28, 2002
// Authors: Daniel Cotting
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

#ifndef __PLANEROJECTION_H_
#define __PLANEPROJECTION_H_

#include "MySurfelList.h"
#include "Patch.h"
#include "ProjectionInterface.h"

/** 
 * Projects a patch of the original object onto the surface of the verification object.
 * The surface is defined by the three nearest neighbours of the point to project.
 */
class PlaneProjection: public ProjectionInterface {
public:

	/**
	 * Projects the patch <tt>originalSurfelPatch</tt> onto the surface of the verification 
	 * object defined by <tt>verificationSurfelList</tt>.
	 *
	 * @param originalSurfelPatch The patch to project.
	 * @param verificationSurfelList The surface to project the patch onto.
	 * @return The projected patch.
	 */
	SurfelCollection* projectPatch(Patch* originalSurfelPatch, MySurfelList* verificationSurfelList);

	/**
	 * Returns the name of this module.
	 *
	 * @return The name of this module.
	 */
	const char* getModuleName() const;

	/**
	 * Returns the description of this module.
	 *
	 * @return The description of this module.
	 */
	const char* getModuleDescription() const;
};

#endif __PLANEPROJECTION_H_

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
