//
// Title:   WatermarkPlugin.cpp
// Created: November 28, 2002
// Authors: Daniel Cotting
//
// Copyright (c) 2001, 2002, Computer Graphics Lab, ETH Zurich
//
// This file is part of the Pointshop3D system.
// See http://www.pointshop3d.com/ for more information.
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of
// the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public
// License along with this program; if not, write to the Free
// Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.
//
// Contact info@pointshop3d.com if any conditions of this
// licensing are not clear to you.
//

/**
 * @file WatermarkPlugin.cpp
 * @brief Plugin applying a watermark to the selection or active object.
 *
 * @author Daniel Cotting
 */

#include <stdio.h>
#include <qmessagebox.h>

#include "WatermarkPlugin.h"
#include "WatermarkDialogImpl.h"
#include "WatermarkingInterface.h"
#include "PrivateWatermarking.h"
#include "PublicWatermarking.h"
#include "SteganoWatermarking.h"
#include "../../../Core/Scene/src/Scene.h"

/**
 * Description of the plugin.
 */
static const char *whatsThisText = "Embeds a watermark into the active object or extract one from it.";
                                  
/**
 * Constructor for this plugin (empty).
 */
WatermarkPlugin::WatermarkPlugin() {}

/**
 * Destructor for this plugin (empty).
 */
WatermarkPlugin::~WatermarkPlugin() {}

void WatermarkPlugin::execute() {

	// create data structure with the currently available watermarking algorithms
	WatermarkingInterface* watermarkingAlgorithms[2];
	watermarkingAlgorithms[0] = new PrivateWatermarking();
	watermarkingAlgorithms[1] = NULL;

	// uncomment the following few lines to activate the watermarking schemes in development
	// WatermarkingInterface* watermarkingAlgorithms[4];
	// watermarkingAlgorithms[0] = new PrivateWatermarking();
	// watermarkingAlgorithms[1] = new PublicWatermarking();
	// watermarkingAlgorithms[2] = new SteganoWatermarking();
	// watermarkingAlgorithms[3] = NULL;

	WatermarkDialogImpl watermarkDialog(watermarkingAlgorithms, 0, "Watermark", true);
	watermarkDialog.show();
	watermarkDialog.raise();
} 

bool WatermarkPlugin::isAvailable() const {
	return this->checkPluginAvailability();
}

// ***************
// private methods
// ***************

bool WatermarkPlugin::checkPluginAvailability() const {
	return (Scene::getInstance()->getNofObjects() > 0);
}

// ****************
// access functions
// ****************

PLUGIN_API PluginInterface *createPlugin() {
	return new WatermarkPlugin();
}

PLUGIN_API const char *getPluginName() {
	return "Watermark";
}

PLUGIN_API const char *getPluginDescription() {
	return whatsThisText;
}

// Some Emacs-Hints -- please don't remove:
//
//  Local Variables:
//  mode:C++
//  tab-width:4
//  End:
